pub(crate) struct GenericInProcessExecutorInner<HT, OT, S>where
HT: ExecutorHooksTuple<S>,
OT: ObserversTuple<S>,
S: State,{
pub(super) observers: OT,
pub(super) hooks: HT,
phantom: PhantomData<S>,
}Expand description
The internal state of GenericInProcessExecutor.
Fields
observers: OTThe observers, observing each run
hooks: HTphantom: PhantomData<S>Implementations
Sourceimpl<HT, OT, S> GenericInProcessExecutorInner<HT, OT, S>where
HT: ExecutorHooksTuple<S>,
OT: ObserversTuple<S>,
S: State,
impl<HT, OT, S> GenericInProcessExecutorInner<HT, OT, S>where
HT: ExecutorHooksTuple<S>,
OT: ObserversTuple<S>,
S: State,
Sourcepub(crate) unsafe fn enter_target<EM, Z>(
&mut self,
_fuzzer: &mut Z,
_state: &mut <Self as UsesState>::State,
_mgr: &mut EM,
_input: &<Self as UsesInput>::Input,
_executor_ptr: *const c_void,
)
pub(crate) unsafe fn enter_target<EM, Z>( &mut self, _fuzzer: &mut Z, _state: &mut <Self as UsesState>::State, _mgr: &mut EM, _input: &<Self as UsesInput>::Input, _executor_ptr: *const c_void, )
This function marks the boundary between the fuzzer and the target
Sourcepub(crate) fn leave_target<EM, Z>(
&mut self,
_fuzzer: &mut Z,
_state: &mut <Self as UsesState>::State,
_mgr: &mut EM,
_input: &<Self as UsesInput>::Input,
)
pub(crate) fn leave_target<EM, Z>( &mut self, _fuzzer: &mut Z, _state: &mut <Self as UsesState>::State, _mgr: &mut EM, _input: &<Self as UsesInput>::Input, )
This function marks the boundary between the fuzzer and the target
Sourceimpl<HT, OT, S> GenericInProcessExecutorInner<HT, OT, S>where
HT: ExecutorHooksTuple<S>,
OT: ObserversTuple<S>,
S: HasExecutions + HasSolutions + HasCorpus + State,
impl<HT, OT, S> GenericInProcessExecutorInner<HT, OT, S>where
HT: ExecutorHooksTuple<S>,
OT: ObserversTuple<S>,
S: HasExecutions + HasSolutions + HasCorpus + State,
Sourcepub(crate) fn new<EM, OF, Z>(
hooks: HT,
observers: OT,
_fuzzer: &mut Z,
_event_mgr: &mut EM,
) -> Result<Self, Error>where
EM: EventFirer<State = S> + EventRestarter,
Z: HasObjective<Objective = OF, State = S>,
pub(crate) fn new<EM, OF, Z>(
hooks: HT,
observers: OT,
_fuzzer: &mut Z,
_event_mgr: &mut EM,
) -> Result<Self, Error>where
EM: EventFirer<State = S> + EventRestarter,
Z: HasObjective<Objective = OF, State = S>,
Create a new in mem executor. Caution: crash and restart in one of them will lead to odd behavior if multiple are used, depending on different corpus or state.
hooks- the hooks run before and after the harness’s executionharness_fn- the harness, executing the functionobservers- the observers observing the target during execution
This may return an error on unix, if signal handler setup fails